import {
  requireNativeComponent,
  UIManager,
  Platform,
  ViewStyle,
  findNodeHandle,
  View,
} from 'react-native';
import React, { forwardRef } from 'react';
import type { MutableRefObject, PropsWithChildren } from 'react';

type Action = { id: string; title: string };
export type PopupMenuProps = {
  actions: Array<Action>;
  onActionPress?: (event: { nativeEvent: { id: string } }) => void;
  style?: ViewStyle;
};

const ComponentName = 'PopupMenuView';
let RCTPopupMenuView =
  UIManager.getViewManagerConfig(ComponentName) != null
    ? requireNativeComponent<PopupMenuProps>(ComponentName)
    : null;

const IS_ANDROID = Platform.OS === 'android';
if (IS_ANDROID && !RCTPopupMenuView) {
  throw new Error(
    `The package '@popupmenu/react-native-popup-menu' doesn't seem to be linked. Make sure: \n\n` +
      Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
      '- You rebuilt the app after installing the package\n' +
      '- You are not using Expo managed workflow\n'
  );
}

export const PopupMenu = forwardRef<any, PropsWithChildren<PopupMenuProps>>(
  (props, ref) => {
    return IS_ANDROID ? (
      // @ts-ignore
      <RCTPopupMenuView {...props} ref={ref} />
    ) : (
      <View {...props} ref={ref} />
    );
  }
);

export function showPopupMenu(
  popupMenuRef: MutableRefObject<any>,
  anchorRef: MutableRefObject<any>
) {
  const popNode = findNodeHandle(popupMenuRef.current);
  if (popNode === null) {
    console.error(
      `Cannot find PopupMenu node, did you forget to set ref to PopupMenu?`
    );
    return;
  }
  const anchorNode = findNodeHandle(anchorRef.current);
  if (anchorNode === null) {
    console.error(
      `Cannot find anchor node, did you forget to set ref to anchor?`
    );
    return;
  }
  UIManager.dispatchViewManagerCommand(popNode, 'show', [anchorNode]);
}
